@@ -16,22 +16,22 @@
 
 # pylint: disable=invalid-name
 
-__version__ = '0.18.0'
+__version__ = '0.19.0'
 __license__ = 'Apache-2.0'
 __author__ = 'OpTree Contributors'
 __release__ = False
 
 if not __release__:
-    import os
     import subprocess
+    from pathlib import Path
 
-    root_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+    root_dir = Path(__file__).absolute().parent.parent
     try:
         prefix, sep, suffix = (
             subprocess.check_output(  # noqa: S603
                 [  # noqa: S607
                     'git',
-                    f'--git-dir={os.path.join(root_dir, ".git")}',
+                    f'--git-dir={root_dir / ".git"}',
                     'describe',
                     '--abbrev=7',
                 ],
@@ -39,6 +39,7 @@ if not __release__:
                 stderr=subprocess.DEVNULL,
                 text=True,
                 encoding='utf-8',
+                timeout=120.0,
             )
             .strip()
             .lstrip('v')
@@ -54,7 +55,7 @@ if not __release__:
         else:
             __version__ = prefix
         del prefix, sep, suffix
-    except (OSError, subprocess.CalledProcessError):
+    except (OSError, RuntimeError, subprocess.SubprocessError):
         pass
 
-    del os, subprocess, root_dir
+    del Path, subprocess, root_dir
